northstarapi

package
v0.0.0-...-1c95f08 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 2, 2018 License: Apache-2.0 Imports: 11 Imported by: 0

Documentation

Index

Constants

const (
	ExecutionsPath = "callbacks"
)

Variables

This section is empty.

Functions

This section is empty.

Types

type InternalClient

type InternalClient struct {
	// contains filtered or unexported fields
}

InternalClient defines the type used to represent a service client.

func NewInternalClient

func NewInternalClient(protocol, hostAndPort string) (*InternalClient, error)

NewInternalClient returns a new instance of the internal client.

func (*InternalClient) ExecutionCallback

func (client *InternalClient) ExecutionCallback(response *model.ExecutionResponse) *management.Error

ExecutionCallback processess the callback for an execution.

type Service

type Service struct {
	// contains filtered or unexported fields
}

Defines the type that represents the service.

func NewService

func NewService() (*Service, error)

Returns a new service instance.

func (*Service) Start

func (service *Service) Start() (err error)

Start starts listening for incoming requests on default service port.

Jump to