handler

package
v0.0.0-...-1c95f08 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 2, 2018 License: Apache-2.0 Imports: 16 Imported by: 0

Documentation

Index

Constants

const (
	// Defines the supported custom headers.
	CallBackHeader = "x-vz-callback-url"
)

Variables

This section is empty.

Functions

This section is empty.

Types

type Controller

type Controller struct {
	// contains filtered or unexported fields
}

Defines the service controller. This type implements the HTTP handler methods for the service API.

func NewController

func NewController() (*Controller, error)

Returns a new Controller.

func (*Controller) Bind

func (controller *Controller) Bind(context *gin.Context, resource interface{}) error

Helper method used to bind body based on supported content types.

func (*Controller) CreateNotebook

func (controller *Controller) CreateNotebook(context *gin.Context)

Creates a new notebook.

func (*Controller) CreateSchedule

func (controller *Controller) CreateSchedule(context *gin.Context)

Creates a new schedule for specified transformation id.

func (*Controller) CreateTemplate

func (controller *Controller) CreateTemplate(context *gin.Context)

Creates a new template.

func (*Controller) CreateTransformation

func (controller *Controller) CreateTransformation(context *gin.Context)

Creates a new transformation.

func (*Controller) DeleteNotebook

func (controller *Controller) DeleteNotebook(context *gin.Context)

Deletes the notebook with the specified id.

func (*Controller) DeleteSchedule

func (controller *Controller) DeleteSchedule(context *gin.Context)

Deletes the schedule for specified transformation id.

func (*Controller) DeleteTemplate

func (controller *Controller) DeleteTemplate(context *gin.Context)

Deletes the templaye with the specified id.

func (*Controller) DeleteTransformation

func (controller *Controller) DeleteTransformation(context *gin.Context)

Deletes the transformation with the specified id.

func (*Controller) ExecuteCell

func (controller *Controller) ExecuteCell(context *gin.Context)

Executes a specific cell action.

func (*Controller) ExecuteNotebookCell

func (controller *Controller) ExecuteNotebookCell(context *gin.Context)

Executes a specified notebook cell.

func (*Controller) ExecuteTransformation

func (controller *Controller) ExecuteTransformation(context *gin.Context)

Updates the transformation with the specified id.

func (*Controller) ExecutionCallback

func (controller *Controller) ExecutionCallback(context *gin.Context)

ExecutionCallback processes the results of an execution

func (*Controller) GetExecution

func (controller *Controller) GetExecution(context *gin.Context)

GetExecution gets the requested execution

func (*Controller) GetNotebook

func (controller *Controller) GetNotebook(context *gin.Context)

GetNotebook returns the notebook with the specified id.

func (*Controller) GetNotebookUsers

func (controller *Controller) GetNotebookUsers(context *gin.Context)

GetNotebook returns the users of the notebook with the specified id.

func (*Controller) GetObject

func (controller *Controller) GetObject(context *gin.Context)

GetObject returns the specified object

func (*Controller) GetSchedule

func (controller *Controller) GetSchedule(context *gin.Context)

Gets the schedule for specified transformation id.

func (*Controller) GetStream

func (controller *Controller) GetStream(context *gin.Context)

func (*Controller) GetTemplate

func (controller *Controller) GetTemplate(context *gin.Context)

Returns the template with the specified id.

func (*Controller) GetTransformation

func (controller *Controller) GetTransformation(context *gin.Context)

Returns the transformation with the specified id.

func (*Controller) GetTransformationResults

func (controller *Controller) GetTransformationResults(context *gin.Context)

func (*Controller) ListBuckets

func (controller *Controller) ListBuckets(context *gin.Context)

ListBuckets retrieves a list of buckets belonging to the user

func (*Controller) ListExecutions

func (controller *Controller) ListExecutions(context *gin.Context)

ListExecutions lists all executions for the account

func (*Controller) ListNotebooks

func (controller *Controller) ListNotebooks(context *gin.Context)

ListNotebooks returns the notebooks for the authenticated user.

func (*Controller) ListObjects

func (controller *Controller) ListObjects(context *gin.Context)

ListObjects retrieves a list of files belonging to the user

func (*Controller) ListStreams

func (controller *Controller) ListStreams(context *gin.Context)

func (*Controller) ListTemplates

func (controller *Controller) ListTemplates(context *gin.Context)

Returns the templates for the authenticated user.

func (*Controller) ListTransformations

func (controller *Controller) ListTransformations(context *gin.Context)

Returns the transformations associated with the authenticated user.

func (*Controller) RemoveStream

func (controller *Controller) RemoveStream(context *gin.Context)

func (*Controller) RenderServiceError

func (controller *Controller) RenderServiceError(context *gin.Context, serviceError *management.Error)

Helper method used to render http response from given management error object.

func (*Controller) SearchUsers

func (controller *Controller) SearchUsers(context *gin.Context)

Creates a new runtime.

func (*Controller) StopExecution

func (controller *Controller) StopExecution(context *gin.Context)

StopExecution stops the specified execution

func (*Controller) TriggerExecution

func (controller *Controller) TriggerExecution(context *gin.Context)

TriggerExecution triggers an execution

func (*Controller) UpdateNotebook

func (controller *Controller) UpdateNotebook(context *gin.Context)

UpdateNotebook updates the notebook with the specified id.

func (*Controller) UpdateNotebookUsers

func (controller *Controller) UpdateNotebookUsers(context *gin.Context)

UpdateNotebookUsers updates the users associated with the specified notebook id.

func (*Controller) UpdateTransformation

func (controller *Controller) UpdateTransformation(context *gin.Context)

Updates the transformation with the specified id.

Jump to