Documentation
¶
Index ¶
Constants ¶
const (
ExecutionsPath = "callbacks"
)
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type InternalClient ¶
type InternalClient struct {
// contains filtered or unexported fields
}
InternalClient defines the type used to represent a service client.
func NewInternalClient ¶
func NewInternalClient(protocol, hostAndPort string) (*InternalClient, error)
NewInternalClient returns a new instance of the internal client.
func (*InternalClient) ExecutionCallback ¶
func (client *InternalClient) ExecutionCallback(response *model.ExecutionResponse) *management.Error
ExecutionCallback processess the callback for an execution.
Click to show internal directories.
Click to hide internal directories.